==> pandoc-crossref-0.3.19-64-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-3M5vPbKwOryKQvbBwlftZP-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-3M5vPbKwOryKQvbBwlftZP-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  f02fae495f0a6ab70eb17497fa461f82
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-3M5vPbKwOryKQvbBwlftZP-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.0-KpMB7tkHt2SeLFNAdwi3G
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.1.12.2-Hlx1osOtjusARtmJdeAL2z
    pandoc-types-1.23.1-HHgE9YCt5FyBsLZfoPgpQ8
    syb-0.7.2.4-7rM6H2Cx7RdIPDVFkspy8A template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-6FIAh31SLg9Gm0tQEepRLF

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-ExS1KqX8C3rJfuXfJyD8ur
key:                  pandoc-crossref-0.3.19-ExS1KqX8C3rJfuXfJyD8ur
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  e3070739fdd7a3a327d9ee2de94ce765
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-ExS1KqX8C3rJfuXfJyD8ur
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.1.12.2-Hlx1osOtjusARtmJdeAL2z
    pandoc-crossref-0.3.19-3M5vPbKwOryKQvbBwlftZP-pandoc-crossref-internal
    pandoc-types-1.23.1-HHgE9YCt5FyBsLZfoPgpQ8 text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.19-65-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-2pqMyIDxjZv2ftfLAthgs4-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-2pqMyIDxjZv2ftfLAthgs4-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  7d104c676c804dd297f7dcfbd953ac19
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-2pqMyIDxjZv2ftfLAthgs4-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.0-KpMB7tkHt2SeLFNAdwi3G
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.1.12.2-4q0LstAFve4JqQKLBAvfcE
    pandoc-types-1.23.1-HHgE9YCt5FyBsLZfoPgpQ8
    syb-0.7.2.4-7rM6H2Cx7RdIPDVFkspy8A template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-6FIAh31SLg9Gm0tQEepRLF

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-EREpLej6ulW7P9Wj5BRbH8
key:                  pandoc-crossref-0.3.19-EREpLej6ulW7P9Wj5BRbH8
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  9707762e203c63e4a34c533f00ca0ef2
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-EREpLej6ulW7P9Wj5BRbH8
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.1.12.2-4q0LstAFve4JqQKLBAvfcE
    pandoc-crossref-0.3.19-2pqMyIDxjZv2ftfLAthgs4-pandoc-crossref-internal
    pandoc-types-1.23.1-HHgE9YCt5FyBsLZfoPgpQ8 text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
